==> exit-options_23.5.01.tar.xz: exit-options-23.5.01/translations/exit-options_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Lock Screen</source>
        <translation>Lås skjermen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Log Out</source>
        <translation>Logg ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Suspend</source>
        <translation>Hvilemodus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Reboot</source>
        <translation>Omstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Shutdown</source>
        <translation>Avslutter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <location filename="../main.cpp" line="50"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Sprettoppvindu med avslutningsalternativer for MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>Display buttons in a vertical window</source>
        <translation>Vis knapper i et loddrett vindu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Vis knapper i et vannrett vindu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Timeout duration in seconds</source>
        <translation>Tidsavbrudd i sekunder</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>bruk -v eller --vertical for å vise knapper loddrett
bruk -h eller --horizontal for å vise knapper vannrett.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Bruk: exit-options [alternativer]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Options:</source>
        <translation>Alternativer:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, --horizontal	 Vis knapper vannrett</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>-v, --vertical	 Vis knapper loddrett</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, --timeout &lt;sec&gt;	Tidsavbrudd i sekunder
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Visningsretningen vil huskes og brukes neste gang programmet startes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Dette kan også angis som &apos;layout=horizontal&apos; eller &apos;layout=vertical&apos; i ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Definer selvvalgte ikoner ved å legge til IconName=/sti/ikonnavn.utv i fila exit-options.conf. Hvilke ikoner som overstyres: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Andre alternativer som kan angis i fila «exit-options.conf»: %1</translation>
    </message>
</context>
</TS>

==> exit-options_23.5.04.tar.xz: exit-options-23.5.04/translations/exit-options_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation>Omstart av Fluxbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Lock Screen</source>
        <translation>Lås skjermen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Log Out</source>
        <translation>Logg ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="27"/>
        <source>Suspend</source>
        <translation>Hvilemodus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="27"/>
        <source>Reboot</source>
        <translation>Omstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="27"/>
        <source>Shutdown</source>
        <translation>Avslutter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Sprettoppvindu med avslutningsalternativer for MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation>Vis knapper i et loddrett vindu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Vis knapper i et vannrett vindu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation>Tidsavbrudd i sekunder</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>bruk -v eller --vertical for å vise knapper loddrett
bruk -h eller --horizontal for å vise knapper vannrett.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Bruk: exit-options [alternativer]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation>Alternativer:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, --horizontal	 Vis knapper vannrett</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>-v, --vertical	 Vis knapper loddrett</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, --timeout &lt;sec&gt;	Tidsavbrudd i sekunder
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Visningsretningen vil huskes og brukes neste gang programmet startes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Dette kan også angis som &apos;layout=horizontal&apos; eller &apos;layout=vertical&apos; i ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>Skriv «timeout=X» i exit-options.conf for å velge tidsavbrudd (X er tidsavbruddet i sekunder).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Definer selvvalgte ikoner ved å legge til IconName=/sti/ikonnavn.utv i fila exit-options.conf. Hvilke ikoner som overstyres: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Andre alternativer som kan angis i fila «exit-options.conf»: %1</translation>
    </message>
</context>
</TS>
